@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class clusterController(GracieBaseAPI):
-    """Cluster"""
+    """Cluster Controller"""
 
     _controller_name = "clusterController"
 
