@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class clusterGroupController(GracieBaseAPI):
-    """Сluster group"""
+    """Cluster Group Controller"""
 
     _controller_name = "clusterGroupController"
 
