@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class skillsetController(GracieBaseAPI):
-    """Skillset"""
+    """Skillset Controller"""
 
     _controller_name = "skillsetController"
 
