@@ -10,7 +10,7 @@ class summarizerController(GracieBaseAPI):
         """
 
         Args:
-            inputLanguageId: (string): inputLanguageId
+            languageId: (string): languageId
             maxSentences: (integer): maxSentences
             text: (type): text
 
@@ -21,7 +21,7 @@ class summarizerController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'inputLanguageId': {'name': 'inputLanguageId', 'required': False, 'in': 'query'}, 'maxSentences': {'name': 'maxSentences', 'required': True, 'in': 'query'}, 'text': {'name': 'text', 'required': True, 'in': 'body'}}
+        all_api_parameters = {'languageId': {'name': 'languageId', 'required': False, 'in': 'query'}, 'maxSentences': {'name': 'maxSentences', 'required': True, 'in': 'query'}, 'text': {'name': 'text', 'required': True, 'in': 'body'}}
         parameters_names_map = {}
         api = '/summarize'
         actions = ['post']
