@@ -10,7 +10,7 @@ class testClassesController(GracieBaseAPI):
         """
 
         Args:
-            className: (string): { "skillsets", "topics" }
+            className: (string): className
             languageId: (string): languageId
 
         Consumes:
