@@ -27,6 +27,28 @@ class testController(GracieBaseAPI):
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
+    def extractDocuments(self, files, **kwargs):
+        """
+
+        Args:
+            files: (array): files
+            languageId: (string): languageId
+
+        Consumes:
+            application/json
+
+        Returns:
+            application/json;charset=UTF-8
+        """
+
+        all_api_parameters = {'files': {'name': 'files', 'required': True, 'in': 'formData'}, 'languageId': {'name': 'languageId', 'required': False, 'in': 'query'}}
+        parameters_names_map = {}
+        api = '/test/extractDocuments'
+        actions = ['post']
+        consumes = ['application/json']
+        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+
     def test(self, argInteger, argIntegerArray, argString, argStringArray, **kwargs):
         """
 
