@@ -6,7 +6,7 @@ class testRunsController(GracieBaseAPI):
 
     _controller_name = "testRunsController"
 
-    def export(self, testDocumentId):
+    def exportDatabases(self, testDocumentId):
         """
 
         Args:
@@ -21,7 +21,7 @@ class testRunsController(GracieBaseAPI):
 
         all_api_parameters = {'testDocumentId': {'name': 'testDocumentId', 'required': True, 'in': 'query'}}
         parameters_names_map = {}
-        api = '/test-runs/export'
+        api = '/test-runs/exportDatabases'
         actions = ['post']
         consumes = ['application/json']
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
