@@ -2,14 +2,15 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class topicController(GracieBaseAPI):
-    """Topic"""
+    """Topic Controller"""
 
     _controller_name = "topicController"
 
-    def add(self, name):
+    def add(self, name, **kwargs):
         """
 
         Args:
+            description: (string): description
             name: (string): name
 
         Consumes:
@@ -19,7 +20,7 @@ class topicController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'name': {'name': 'name', 'required': True, 'in': 'query'}}
+        all_api_parameters = {'description': {'name': 'description', 'required': False, 'in': 'query'}, 'name': {'name': 'name', 'required': True, 'in': 'query'}}
         parameters_names_map = {}
         api = '/topic/add'
         actions = ['post']
@@ -48,6 +49,28 @@ class topicController(GracieBaseAPI):
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
+    def edit(self, id, **kwargs):
+        """
+
+        Args:
+            description: (string): description
+            id: (string): id
+
+        Consumes:
+            application/json
+
+        Returns:
+            application/json;charset=UTF-8
+        """
+
+        all_api_parameters = {'description': {'name': 'description', 'required': False, 'in': 'query'}, 'id': {'name': 'id', 'required': True, 'in': 'query'}}
+        parameters_names_map = {}
+        api = '/topic/edit'
+        actions = ['post']
+        consumes = ['application/json']
+        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+
     def list(self, **kwargs):
         """
 
