@@ -31,6 +31,27 @@ class topicEntitiesController(GracieBaseAPI):
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
+    def bulkDelete(self, ids):
+        """
+
+        Args:
+            ids: (array): ids
+
+        Consumes:
+            application/json
+
+        Returns:
+            application/json;charset=UTF-8
+        """
+
+        all_api_parameters = {'ids': {'name': 'ids', 'required': True, 'in': 'query'}}
+        parameters_names_map = {}
+        api = '/topicEntity/bulkDelete'
+        actions = ['post']
+        consumes = ['application/json']
+        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+
     def clone(self, id, topicTypeId, **kwargs):
         """
 
